@@ -46,8 +46,10 @@ void ConfigHandler::setConfig(KScreen::ConfigPtr config)
     m_lastNormalizedScreenSize = screenSize();
 
     connect(m_outputModel, &OutputModel::dataChanged, this, [this](const QModelIndex &topLeft, const QModelIndex &bottomRight, const QList<int> &roles) {
+        Q_UNUSED(topLeft)
         Q_UNUSED(bottomRight)
-        // Do not run checks during interactive reaarange
+        Q_UNUSED(roles)
+        // Do not run checks during interactive rearrange
         if (!m_outputModel->isMoving()) {
             checkNeedsSave();
         }
@@ -167,7 +169,11 @@ bool ConfigHandler::checkSaveandTestCommon(bool isSaveCheck)
                     || (isSaveCheck && output->sdrGamutWideness() != config->sdrGamutWideness())
                     || output->colorProfileSource() != config->colorProfileSource()
                     || (isSaveCheck && output->brightness() != config->brightness())
-                    || output->colorPowerPreference() != config->colorPowerPreference()) {
+                    || output->colorPowerPreference() != config->colorPowerPreference()
+                    || output->replicationSource() != config->replicationSource()
+                    || output->ddcCiAllowed() != config->ddcCiAllowed()
+                    || output->maxBitsPerColor() != config->maxBitsPerColor()
+                    || (isSaveCheck && output->edrPolicy() != config->edrPolicy())) {
                         return true;
                     }
             }
@@ -177,6 +183,23 @@ bool ConfigHandler::checkSaveandTestCommon(bool isSaveCheck)
     return false;
 }
 
+void ConfigHandler::prepareForSave()
+{
+    const auto outputs = m_config->connectedOutputs();
+    for (const auto &output : outputs) {
+        const QString hash = output->hashMd5();
+        const auto configs = m_initialConfig->outputs();
+        for (const auto &config : configs) {
+            if (hash != config->hashMd5()) {
+                continue;
+            }
+            if (config->ddcCiAllowed() && !output->ddcCiAllowed()) {
+                m_outputModel->setData(m_outputModel->indexForOutput(output), 1.0, OutputModel::BrightnessRole);
+            }
+        }
+    }
+}
+
 QSize ConfigHandler::screenSize() const
 {
     int width = 0, height = 0;
