@@ -10,7 +10,7 @@
 #include <kscreen/edid.h>
 #include <kscreen/mode.h>
 
-#include "../common/utils.h"
+#include "common/utils.h"
 #include "config_handler.h"
 
 #include <KLocalizedString>
@@ -139,6 +139,22 @@ QVariant OutputModel::data(const QModelIndex &index, int role) const
         return output->name();
     case EdrPolicyRole:
         return static_cast<uint32_t>(output->edrPolicy());
+    case BitsPerColorOptionsPreferEfficiencyRole: {
+        QVariantList options;
+        options.push_back(0);
+        for (uint32_t bpc = output->bitsPerColorRange().min; bpc <= std::min(output->bitsPerColorRange().max, 10u); bpc += 2) {
+            options.push_back(bpc);
+        }
+        return options;
+    }
+    case BitsPerColorOptionsPreferAccuracyRole: {
+        QVariantList options;
+        options.push_back(0);
+        for (uint32_t bpc = output->bitsPerColorRange().min; bpc <= std::min(output->bitsPerColorRange().max, 16u); bpc += 2) {
+            options.push_back(bpc);
+        }
+        return options;
+    }
     }
     return QVariant();
 }
@@ -370,6 +386,8 @@ QHash<int, QByteArray> OutputModel::roleNames() const
     roles[PeakBrightnessOverride] = "peakBrightnessOverride";
     roles[OutputNameRole] = "name";
     roles[EdrPolicyRole] = "edrPolicy";
+    roles[BitsPerColorOptionsPreferEfficiencyRole] = "bitsPerColorOptionsPreferEfficiency";
+    roles[BitsPerColorOptionsPreferAccuracyRole] = "bitsPerColorOptionsPreferAccuracy";
     return roles;
 }
 
@@ -1202,9 +1220,6 @@ bool snapToBottom(const QRect &target, const QSize &size, QPoint &dest)
 
 bool snapVertical(const QRect &target, const QSize &size, QPoint &dest)
 {
-    if (snapToMiddle(target, size, dest)) {
-        return true;
-    }
     if (snapToBottom(target, size, dest)) {
         return true;
     }
@@ -1231,11 +1246,6 @@ void OutputModel::snap(const Output &output, QPoint &dest)
         const QRect target(other.pos, other.ptr->geometry().size());
         const bool xOverlap = dest.x() <= target.x() + target.width() && target.x() <= dest.x() + size.width();
         const bool yOverlap = dest.y() <= target.y() + target.height() && target.y() <= dest.y() + size.height();
-        // Special special case, snap to center if centers are close
-        if (std::abs((outputRect.center() - target.center()).manhattanLength()) < s_snapArea * 2) {
-            dest = target.center() - (outputRect.center() - outputRect.topLeft());
-            return;
-        }
         if (xOverlap) {
             const int topDist = std::abs(dest.y() - target.y() - target.height());
             const int bottomDist = std::abs(outputRect.y() + outputRect.height() - target.y());
