@@ -9,10 +9,10 @@
 */
 #include "daemon.h"
 
+#include "common/kscreen_daemon_debug.h"
 #include "config.h"
 #include "device.h"
 #include "generator.h"
-#include "kscreen_daemon_debug.h"
 #include "osdservice_interface.h"
 
 #include <kscreen/configmonitor.h>
