@@ -5,7 +5,7 @@
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 #include "../../kded/config.h"
-#include "../../common/globals.h"
+#include "common/globals.h"
 
 #include <QObject>
 #include <QStandardPaths>
